@@ -1,13 +1,12 @@
+# $Id: Dependency.pm,v 1.8 2007/12/13 15:16:03 drhyde Exp $
+#!perl -w
 package CPAN::FindDependencies::Dependency;
 
-require CPAN::FindDependencies;
-
 use strict;
-use warnings;
 
 use vars qw($VERSION);
 
-$VERSION = '2.99_02';
+$VERSION = '2.1';
 
 =head1 NAME
 
@@ -18,7 +17,7 @@ CPAN::FindDependencies::Dependency - object representing a module dependency
     my @dependencies = CPAN::FindDependencies::finddeps("CPAN");
     foreach my $dep (@dependencies) {
         print ' ' x $dep->depth();
-        print $dep->name().' (dist: '.$dep->distribution().', mod ver: '.$dep->version().")\n";
+        print $dep->name().' ('.$dep->distribution().")\n";
     }
 
 =head1 METHODS
@@ -49,17 +48,7 @@ The name of the distribution containing the module
 =cut
 
 sub distribution {
-    $_[0]->{distribution}->prefix();
-}
-
-=head2 version
-
-The minimum required version (if specified) of the module
-
-=cut
-
-sub version {
-  $_[0]->{version}
+    $_[0]->{p}->package($_[0]->name())->distribution()->prefix();
 }
 
 =head2 depth
@@ -87,12 +76,12 @@ None known
 
 I welcome feedback about my code, including constructive criticism
 and bug reports.  The best bug reports include files that I can add
-to the test suite, which fail with the current code in my git repo and
-will pass once I've fixed the bug
+to the test suite, which fail with the current code in CVS and will
+pass once I've fixed the bug
 
 =head1 SOURCE CODE REPOSITORY
 
-L<git://github.com/DrHyde/perl-modules-CPAN-FindDependencies.git>
+L<http://www.cantrell.org.uk/cgit/cgit.cgi/perlmodules/>
 
 =head1 SEE ALSO
 
